@@ -62,6 +62,7 @@ Legends = function(...) {
 # -by_row Are the legend grids arranged by rows or by columns?
 # -grid_height The height of legend grid. It can also control the height of the continuous legend if it is horizontal.
 # -grid_width The width of legend grid. It can also control the width of the continuous legend if it is vertical.
+# -tick_length Length of the ticks on the continuous legends. Value should be a `grid::unit` object.
 # -gap If legend grids are put into multiple rows or columns, this controls the gap between neighbouring rows or columns, measured as a `grid::unit` object.
 # -column_gap The same as ``gap``.
 # -row_gap Space between legend rows.
@@ -114,7 +115,7 @@ Legends = function(...) {
 Legend = function(at, labels = at, col_fun, name = NULL, grob = NULL,
 	break_dist = NULL, nrow = NULL, ncol = 1, by_row = FALSE,
 	grid_height = unit(4, "mm"), 
-	grid_width = unit(4, "mm"), 
+	grid_width = unit(4, "mm"), tick_length = unit(0.8, "mm"),
 	gap = unit(2, "mm"), column_gap = gap, row_gap = unit(0, "mm"),
 	labels_gp = gpar(fontsize = 10), labels_rot = 0,
 	border = NULL, background = "#EEEEEE",
@@ -174,8 +175,8 @@ Legend = function(at, labels = at, col_fun, name = NULL, grob = NULL,
 
 		if(direction == "vertical") {
 			legend_body = vertical_continuous_legend_body(at = at, labels = labels, col_fun = col_fun, break_dist = break_dist,
-				grid_height = grid_height, grid_width = grid_width, legend_height = legend_height,
-				labels_gp = labels_gp, border = border)
+				grid_height = grid_height, grid_width = grid_width, tick_length = tick_length, legend_height = legend_height,
+				labels_gp = labels_gp, border = border, legend_gp = legend_gp)
 		} else {
 			legend_extension = unit(0, "mm")
 			if(title_position == "lefttop") {
@@ -186,8 +187,8 @@ Legend = function(at, labels = at, col_fun, name = NULL, grob = NULL,
 				}
 			}
 			legend_body = horizontal_continuous_legend_body(at = at, labels = labels, col_fun = col_fun, break_dist = break_dist,
-				grid_height = grid_height, grid_width = grid_width, legend_width = legend_width,
-				labels_gp = labels_gp, labels_rot = labels_rot, border = border, legend_extension = legend_extension)
+				grid_height = grid_height, grid_width = grid_width, tick_length = tick_length, legend_width = legend_width,
+				labels_gp = labels_gp, labels_rot = labels_rot, border = border, legend_gp = legend_gp, legend_extension = legend_extension)
 		}
 	}
 
@@ -525,12 +526,17 @@ discrete_legend_body = function(at, labels = at, nrow = NULL, ncol = 1, by_row =
 		} else {
 			sgd2$fill = background
 		}
+		if(identical(legend_gp$col, "asis")) {
+			border = "asis"
+		}
 		if(identical(border, "asis")) {
 			sgd2$col = sgd2$fill	
 		} else {
-			sgd2$col = border
+			if(is.null(sgd2$col)) {
+				sgd2$col = border
+			}
 		}
-		
+
 		grid_x = previous_x
 		grid_y = y - (row_height[1:ni] - row_gap)*0.5
 		if(ni == nrow) grid_y[nrow] = y[nrow] - row_height[nrow]*0.5
@@ -605,9 +611,9 @@ discrete_legend_body = function(at, labels = at, nrow = NULL, ncol = 1, by_row =
 
 vertical_continuous_legend_body = function(at, labels = at, col_fun,
 	break_dist = NULL, grid_height = unit(4, "mm"), grid_width = unit(4, "mm"),
-	legend_height = NULL,
+	legend_height = NULL, tick_length = unit(0.8, "mm"),
 	labels_gp = gpar(fontsize = 10),
-	border = NULL) {
+	border = NULL, legend_gp = gpar()) {
 
 	n = length(at)
 	breaks = attr(col_fun, "breaks")
@@ -754,11 +760,15 @@ vertical_continuous_legend_body = function(at, labels = at, col_fun,
 	))
 	
 	## colors
+	if(!at_diff_is_equal) {
+		at = seq(at[1], at[length(at)], length.out = n_labels)
+	}
 	at2 = unlist(lapply(seq_len(n_labels - 1), function(i) {
-		x = seq(at[i], at[i+1], length.out = round((at[i+1]-at[i])/(at[k]-at[1])*100))
+		x = seq(at[i], at[i+1], length.out = max(10, round((at[i+1]-at[i])/(at[k]-at[1])*100)))
 		x = x[-length(x)]
 	}))
 	at2 = c(at2, at[length(at)])
+
 	colors = col_fun(at2)
 	x2 = unit(rep(0, length(colors)), "npc")
 	y2 = seq(0, 1, length.out = length(colors)+1); y2 = y2[-length(y2)]
@@ -769,11 +779,25 @@ vertical_continuous_legend_body = function(at, labels = at, col_fun,
 	y2 = unit.c(offset*0.5, y2, legend_body_height - offset*0.5)
 	hh = unit.c(offset, rep(hh, length(y2)-2), offset)
 	colors = c(colors[1], colors, colors[length(colors)])
+
+	if(is.null(border)) {
+		if(!is.null(legend_gp$col)) {
+			border = legend_gp$col
+		}
+	}
+
+	if(is.null(border)) {
+		legend_gp$col = "white"
+	} else {
+		if(is.null(legend_gp$col)) {
+			legend_gp$col = border
+		}
+	}
 	gl = c(gl, list(
 		rectGrob(x2, rev(y2), width = grid_width, height = hh, just = c("left", "center"),
 			gp = gpar(col = rev(colors), fill = rev(colors))),
-		segmentsGrob(unit(0, "npc"), y, unit(0.8, "mm"), y, gp = gpar(col = ifelse(is.null(border), "white", border))),
-		segmentsGrob(grid_width, y, grid_width - unit(0.8, "mm"), y, gp = gpar(col = ifelse(is.null(border), "white", border)))
+		segmentsGrob(unit(0, "npc"), y, tick_length, y, gp = legend_gp),
+		segmentsGrob(grid_width, y, grid_width - tick_length, y, gp = legend_gp)
 	))
 
 	if(adjust_text_pos) {
@@ -801,8 +825,9 @@ vertical_continuous_legend_body = function(at, labels = at, col_fun,
 	}
 
 	if(!is.null(border)) {
+		legend_gp$fill = "transparent"
 		gl = c(gl, list(
-			rectGrob(width = grid_width, height = legend_height, x = unit(0, "npc"), just = "left", gp = gpar(col = border, fill = "transparent"))
+			rectGrob(width = grid_width, height = legend_height, x = unit(0, "npc"), just = "left", gp = legend_gp)
 		))
 	}
 
@@ -815,9 +840,9 @@ vertical_continuous_legend_body = function(at, labels = at, col_fun,
 
 horizontal_continuous_legend_body = function(at, labels = at, col_fun,
 	break_dist = NULL, grid_height = unit(4, "mm"), grid_width = unit(4, "mm"),
-	legend_width = NULL,
+	legend_width = NULL, tick_length = unit(0.8, "mm"),
 	labels_gp = gpar(fontsize = 10), labels_rot = 0,
-	border = NULL, legend_extension = unit(0, "mm")) {
+	border = NULL, legend_gp = gpar(), legend_extension = unit(0, "mm")) {
 		
 	n = k = length(at)
 	breaks = attr(col_fun, "breaks")
@@ -901,6 +926,11 @@ horizontal_continuous_legend_body = function(at, labels = at, col_fun,
 	if(is.null(legend_width)) legend_width = min_legend_width
 
 	segment_col = border
+	if(is_diff_equal(at)) {
+		at_diff_is_equal = TRUE
+	} else {
+		at_diff_is_equal = FALSE
+	}
 
 	legend_body_width = legend_width
 	legend_body_height = grid_height + labels_padding_top + labels_max_height
@@ -959,6 +989,9 @@ horizontal_continuous_legend_body = function(at, labels = at, col_fun,
 		textGrob(labels, x = labels_x, y = labels_y, just = labels_just, gp = labels_gp, rot = labels_rot)
 	))
 
+	if(!at_diff_is_equal) {
+		at = seq(at[1], at[length(at)], length.out = n_labels)
+	}
 	at2 = unlist(lapply(seq_len(n_labels - 1), function(i) {
 		x = seq(at[i], at[i+1], length.out = round((at[i+1]-at[i])/(at[k]-at[1])*100))
 		x = x[-length(x)]
@@ -975,11 +1008,18 @@ horizontal_continuous_legend_body = function(at, labels = at, col_fun,
 	ww = unit.c(offset + (x2[2] - x2[1])*0.5, rep(ww, length(x2) - 2))
 	colors = c(colors[1], colors)
 
+	if(is.null(border)) {
+		legend_gp$col = "white"
+	} else {
+		if(is.null(legend_gp$col)) {
+			legend_gp$col = border
+		}
+	}
 	gl = c(gl, list(
 		rectGrob(x2, y2, height = grid_height, width = ww, just = c("left", "top"),
 			gp = gpar(col = colors, fill = colors)),
-		segmentsGrob(x, legend_body_height - grid_height, x, legend_body_height - grid_height + unit(0.8, "mm"), gp = gpar(col = ifelse(is.null(border), "white", border))),
-		segmentsGrob(x, legend_body_height - unit(0.8, "mm"), x, legend_body_height, gp = gpar(col = ifelse(is.null(border), "white", border)))
+		segmentsGrob(x, legend_body_height - grid_height, x, legend_body_height - grid_height + tick_length, gp = legend_gp),
+		segmentsGrob(x, legend_body_height - tick_length, x, legend_body_height, gp = legend_gp)
 	))
 
 	if(adjust_text_pos) {
@@ -1007,8 +1047,9 @@ horizontal_continuous_legend_body = function(at, labels = at, col_fun,
 	}
 
 	if(!is.null(border)) {
+		legend_gp$fill = "transparent"
 		gl = c(gl, list(
-			rectGrob(width = legend_width, height = grid_height, y = unit(1, "npc"), just = "top", gp = gpar(col = border, fill = "transparent"))
+			rectGrob(width = legend_width, height = grid_height, y = unit(1, "npc"), just = "top", gp = legend_gp)
 		))
 	}
 
@@ -1482,20 +1523,21 @@ is_diff_equal = function(x) {
 # pch are numeric
 .pointsGrob_as_a_list = function(x, y, pch, gp, size, width, height) {
 	n = length(x)
-	if(any(pch %in% 26:31)) {
+	pch2 = pch; pch2[is.na(pch2)] = -1
+	if(any(pch2 %in% 26:31)) {
 		gl = list()
 		for(i in 1:n) {
-			if(pch[i] == 26) {
+			if(pch2[i] == 26) {
 				gb = segmentsGrob(x[i] - width*0.4, y[i] - height*0.4, x[i] + width*0.4, y[i] + height*0.4, gp = subset_gp(gp[i]))
-			} else if(pch[i] == 27) {
+			} else if(pch2[i] == 27) {
 				gb = segmentsGrob(x[i] + width*0.4, y[i] - height*0.4, x[i] - width*0.4, y[i] + height*0.4, gp = subset_gp(gp[i]))
-			} else if(pch[i] == 28) {
+			} else if(pch2[i] == 28) {
 				gb = segmentsGrob(unit.c(x[i] - width*0.4, x[i] + width*0.4), 
 					              unit.c(y[i] - height*0.4, y[i] - height*0.4),
 					              unit.c(x[i] + width*0.4, x[i] - width*0.4),
 					              unit.c(y[i] + height*0.4, y[i] + height*0.4), 
 					              gp = subset_gp(gp[i]))
-			} else if(pch[i] %in% 29:31) {
+			} else if(pch2[i] %in% 29:31) {
 				stop_wrap("pch in 29:31 is not implemented in Legend().")
 			} else {
 				gb = pointsGrob(x = x[i], y = y[i], pch = pch[i], gp = subset_gp(gp, i), size = size[i])
